function plot_RER(RER, PFIM, data)
%
% Plot RER computed directly or utilizing PFIM. Confidence intervals are
% also plotted.
%
%  ---- INPUT PARAMETERS ----
%   RER: a vector of RERs corresponds to the perturbation matrix, [NoPx1]
%   PFIM: pathwise Fisher Information Matrix, [KxK]
%   data: data structure array
%
%   data.K: number of parameters, [1x1] 
%   data.eps0: percentage of parameter perturbation, [1x1]
%
% (c) Math & Stat, Umass, Amherst, 2014

ind_K = 1:data.K;

NoS = size(RER, 2);
FIMbasedRER = zeros(data.K, NoS);
veps = data.eps0 * eye(data.K);

% compute PFIM-based RER
for i = 1:NoS
    for j = 1:data.K
        FIMbasedRER(j,i) = .5 * (veps(j,:) * PFIM(:,:,i) * veps(j,:)');
    end
end


% normalization
[RER_mean, RER_std, RER_meanci, RER_stdci] = normfit(RER');
[FIMbasedRER_mean, FIMbasedRER_std, FIMbasedRER_meanci, FIMbasedRER_stdci] = normfit(FIMbasedRER');


% plot RER and PFIM-based RER
RER_group = horzcat(RER_mean(ind_K)', FIMbasedRER_mean', RER_mean(data.K+ind_K)');
bar(RER_group, 'group'); hold on;
legend('+\epsilon', 'PFIM-based', '-\epsilon');
xlabel('Various directions');
ylabel('Relative Entropy Rate');
h = gca;
xlabels = data.theta;
set(h,'XTickLabel', xlabels);
colormap gray;

% confidence intervals
X = [ind_K-.225, ind_K, ind_K+.225];
Y = [RER_mean(ind_K), FIMbasedRER_mean, RER_mean(data.K+ind_K)];
YU = [RER_meanci(2,ind_K), FIMbasedRER_meanci(2,ind_K), RER_meanci(2,data.K+ind_K)] - Y;
YL = Y - [RER_meanci(1,ind_K), FIMbasedRER_meanci(1,ind_K), RER_meanci(1,data.K+ind_K)];

errorbar(X,Y,YU,YL, 'k.'); hold off;


