function sim_rxn(data, dname, method)
%
% Simulate the reaction network. Each time-series is interpolated at given
% time instants and stored in .mat files.
%
%  ---- INPUT PARAMETERS ----
%   data: data structure array
%
%   data.M: number of reactions, [1x1]
%   data.N: number of species, [1x1]
%   data.NoJ: number of jumps, [1x1]
%   data.T: final time, [1x1]
%   data.tau: tau leap size,  [1x1]
%   data.X: current population of the system, [Nx1]
%   data.stoichio: stoichiometric matrix, [Mx4]
%   data.ti: sampling time instants, [data.T/dtx1]
%   data.NoS: number of repeated simulations, [1x1]
%   data.cm_rea: connectivity matrix for the reactions, [Mx4]
%   data.cm_spe: connectivity matrix for the species, [NxK+1]
%	data.con: value of reaction constants, [Kx1]
%	data.vprops: cell vector with the propensity functions as strings with numeric coefficients,[Mx1]
%
%   dname: directory for interpolated simulation
%   method: simulation algorithm (ssa, cle or mfa)
%
% ---- OUTPUT PARAMETERS ----
%   .mat file: Interpolated simulation data file.
%
% (c) Math & Stat, Umass, Amherst, 2014

ti = data.ti'; % sampling time instants

% check if directory exists (if not, create it)
tmp = dir(dname);
if isempty(tmp)
    mkdir(dname);
end

% simulate
fprintf(1, 'Simulating reaction network with %s .....\n', method);
tic;

for i = 1:data.NoS 

    % choose simulation algorithm from SSA, CLE and MFA(Default)
    switch method
        case 'SSA' 
            % run SSA
            res = reaction_ssa(data);    

            % interpolate and extract populations from specific time instants 
            X = interp1(res.t, res.species_ts, data.ti, 'nearest'); % reduced, incomplete time series

        case 'CLE'
            % run CLE
            res = reaction_cle(data);

            % interpolate and extract populations from specific time instants 
            X = interp1(res.t, res.species_ts, data.ti, 'linear'); % reduced, incomplete time series

        case 'MFA'
            % run MFA
            res = reaction_mfa(data);
            
            % interpolate and extract populations from specific time instants 
            X = interp1(res.t, res.species_ts, data.ti, 'linear'); % reduced, incomplete time series

        otherwise
            warning('Unexpected simulation method applied.');
    end
    
    
    % create data file names
    fname = sprintf('X_%s_%d.mat', method,i);	
    
    % save 
    save([dname fname], 'X', 'ti');
    
    % show the progress
    fprintf(1, '%.1f%% completed in %.2f seconds.\n', i/data.NoS*100, toc);
end

